#
# spec file for package spec-cleaner
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Vincent Untz <vuntz@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spec-cleaner
Version:        1.2.2
Release:        1.3
Summary:        .spec file cleaner
License:        BSD-3-Clause
URL:            https://github.com/rpm-software-management/spec-cleaner
Source0:        https://github.com/rpm-software-management/spec-cleaner/archive/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: https://github.com/rpm-software-management/spec-cleaner/commit/fd0f64930a399dfcf4ff5d3e22a8ec9afa37043a
Patch0:         fix_tests_needing_web_connection.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-pytest
BuildRequires:  python3-wheel
# For the pkg_resources used in the binary loader
BuildArch:      noarch

%description
This script cleans spec file according to some arbitrary style guide. The
results it produces should always be checked by someone since it is not and
will never be perfect.

%package format_spec_file
Summary:        Binding replacing OBS service format_spec_file
Requires:       %{name} = %{version}
Conflicts:      obs-service-format_spec_file

%description format_spec_file
Alternative provider of format_spec_file functionality in order to allow
user to use spec-cleaner rather than to stick to perl based format_spec_file.

%prep
%autosetup -p1 -n %{name}-%{name}-%{version}
rm pytest.ini

%build
%if 0%{?mageia}
%py3_build
%else
%python3_pyproject_wheel
%endif

%check
export LANG=en_US.UTF-8
python3 -m pytest -k "not webtest" tests/*-tests.py

%install
%if 0%{?mageia}
%py3_install
%else
%python3_pyproject_install
%endif
%fdupes %{buildroot}%{python3_sitelib}

%files
%license COPYING
%{_bindir}/%{name}
%dir %{_prefix}/lib/obs/
%dir %{_prefix}/lib/obs/service/
%{_prefix}/lib/obs/service/clean_spec_file
%{_prefix}/lib/obs/service/clean_spec_file.service
%{python3_sitelib}/spec_cleaner
%{python3_sitelib}/spec_cleaner-%{version}*-info
%{_datadir}/%{name}

%files format_spec_file
%{_prefix}/lib/obs/service/format_spec_file
%{_prefix}/lib/obs/service/format_spec_file.service

%changelog
* Thu Oct 26 2023 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Wed Oct 25 2023 Kristyna Streitova <kstreitova@suse.com>
- Update to 1.2.2 bsc#1099674:
  * Expand python sitelib glob usage in files
  * Add new head category for PSP macros
  * Make flake8 happy and fix C416
  * avoid adding curly braces to apparmor_reload
  * Bump CodeQL Actions version
  * Do not put curly brackets around python_libalternatives_reset_alternative
  * Try to fix coveralls in github actions
  * Update to actions/checkout@v3 and setup-python@v4
  * Try to increase timeout for urlopen
  * Make flake8 and mypy happy
  * Set headers for urlopen to avoid 403 code
  * ubuntu-latest doesn't support 3.6 anymore
  * Replace calls to w3m with calls to curl
  * move logic that tries to change the URL field to https into _make_secure_url
  * Fix pep8 errors to pass flake8 tests (#296)
  * Extend support for patterns (boo#1195092)
  * update coveralls config
  * Ignore error N818 from pep8-naming for now
  * Fix URL expectations on tests
  * Do not put brackets on %%obsolete_legacy_pattern
  * Fix #287: Incorrect curlification for more systemd-macros
  * Add new script for rpmlint.
  * Use github token directly
- Remove spec-cleaner-psp-macros.patch that is already included in
  1.2.2 release
- Install new *.toml files with licenses
- Add fix_tests_needing_web_connection.patch to temporarily fix
  tests that need internet connection that is not available during
  OBS build. Already fixed upstream in fd0f649
* Tue Oct 24 2023 Dirk Müller <dmueller@suse.com>
- add spec-cleaner-psp-macros.patch to avoid spec-cleaner
  rewriting the location of the psp macro
* Thu Jun 17 2021 Atilla ÖNTAŞ <tarakbumba@gmail.com>
- Fix: Use Mageia specific macro for Mageia builds in spec file
* Tue Nov 17 2020 John Vandenberg <jayvdb@gmail.com>
- Update URLs
- Remove build dependencies on unnecessary pytest plugins
* Thu Oct  1 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.1 bsc#1099674:
  * Use Leap 15.2 as a base for data files
* Wed Aug 26 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%{_prefix}/lib instead of %%{_libexecdir}: obs services are
  explicitly looked for at this location.
* Tue Jun 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0 bsc#1099674:
  * Fix pypi rewritter to work with wheels
  * Do not choke on multiline string macros
* Wed Mar 25 2020 Kristyna Streitova <kstreitova@suse.com>
- Update to 1.1.9 bsc#1099674:
  * Add builtin and comprehensions to catch tad more issues
  * Do not add FIXME comments for already commented lines
  * Add the article to the comment
  * Exclude mysql_testserver calls from bracketing
  * Do not curlify systemd_ordering macro
  * Ignore dephell setup generator macro from bracketing
  * Use github actions and drop travis and tox
  * Use pre-commit framework for the project (it runs black, flake8,
    flake8-docstrings and mypy on every commit)
  * Update README
  * Add %%{dephell_gensetup} macro instead of the full call to
    dephell com
* Thu Jan 30 2020 Kristyna Streitova <kstreitova@suse.com>
- Update to 1.1.8 bsc#1099674:
  * Change libexecdir substitution to do /usr/libexec to %%{_libexecdir}
  * Exclude apache_rex_check from bracketing
  * Add testscase for boolean dependencies that gets mangled currently
  * Do not remove -p0 from autosetup
  * Use %%make_build if possible issue
  * Teach spec-cleaner to not break the %%elif* macros added with
    rpm 4.15
  * Fixup the nested boolean dependencies
  * Fixup whitespace reported by flake8
  * Set explicit urllib timeout issue
  * Replace more stuff for %%make build
* Thu Nov 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.7 bsc#1099674:
  * Fix a duplication with new SUSE copyright line
  * Exclude all pom_ macros from bracketing
* Mon Nov 11 2019 Kristyna Streitova <kstreitova@suse.com>
- Update to 1.1.6 bsc#1099674:
  * Do not remove groups by default. Now, groups are kept untouched
    by default. Introduce a new option '--remove-groups' that
    removes Group tags from the specfile. Remove '--preserve_groups'
    option.
  * Say goodbye to setup.py test usage as it is deprecated
  * Update the copyring and SUSE header string wrt #264
  * Ignore hpc_configure macro from bracketing
* Thu Sep 26 2019 Kristyna Streitova <kstreitova@suse.com>
- Update to 1.1.5 bsc#1099674:
  * Use https in URL in spec-cleaner.spec test
  * Remove duplicated backslash in regexp
  * Parallelize test run
  * Add jupyter_move_config to excludes from bracketing
  * Do not fail if URL is ftp:// or other protocol
  * Make xdist enabled by default on all test runs and add xdist to deps
  * By default remove groups from packages
- remove spec-cleaner-1.1.4_test_https.patch that is no longer needed
* Wed Jul 17 2019 Kristyna Streitova <kstreitova@suse.com>
- Update to 1.1.4 bsc#1099674:
  * Exclude stuff from openstack macros
  * Replace 'http' with 'https' in URL
  * Replace legacy packageand() with 'and' expression
  * Replace pwdutils with shadow in Requires
  * Add openstack_cleanup_prep to bracketing excludes
  * Do not curlify yast_metainfo and yast_check
  * Fixup the eating of Source lines with whitespace
  * Document '#nospeccleaner' tag
  * Add docstrings to the functions and classes.
  * Use type hints for the most important functions
  * Update README and licences
  * Various small fixes
- add a temporary patch spec-cleaner-1.1.4_test_https.patch
  that fixes a test that fails if there is no internet connection
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.3 bsc#1099674:
  * Convert pytest calls to macros
  * Fix errors in %%python_expand line expansions
  * update licenses list
  * Expand more excludes for curlification
  * Do not add accidental newlines to complex conditions
* Thu Dec 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 1.1.2 bsc#1099674:
  * Fixed qmake macro recommendation
  * More licenses recognised
  * Do not curlify sysuser_create
* Mon Aug 20 2018 tchvatal@suse.com
- Version update to 1.1.1 bsc#1099674:
  * Fix help message not working
  * Make libexecdir opt-in rather than opt-out
  * Account for LICENCE string not just LICENSE
  * Warn about direct qmake/meson usage
  * Use https when mentioning bugzilla in header
  * Use tuples on some places rather than lists
* Sun Jul  1 2018 tchvatal@suse.com
- Version update to 1.1.0 bsc#1099674:
  * Fix issue with previous release not finding datadirs
* Fri Jun 29 2018 tchvatal@suse.com
- Version uppdate to 1.0.9 bsc#1099674:
  * Move some checks from rpmlint to be autochecked
  * Dropped support of py2
  * Fixed error reported on parsing non-utf spec-file
  * Leap 15.0 used as base for conversions to pkgconfig/etc.
* Fri May 11 2018 tchvatal@suse.com
- Version update to 1.0.8 bsc#1092933:
  * Be case insensitive on license detection
  * Exclude limit_build from bracketing
  * Replace _libexecdir as we now do not really bother about
    SLE11
* Thu Apr 12 2018 tchvatal@suse.com
- Version update to 1.0.7 bsc#1089297:
  * Fix haskell macro bracketing
  * Fix firewalld macros bracketing
* Tue Mar  6 2018 tchvatal@suse.com
- Version update to 1.0.6 release:
  * Fixes license conversions to spdx3.0
  * Allows better parsing of pattern packages
  * Various manpage suffixing fixes
  * Added more things to exclude bracketing
* Wed Feb 28 2018 tchvatal@suse.com
- Fix issue with the %%doc -> %%license conversion in some complex
  cases, multiple licenses at once, prefixed licenses
* Thu Feb 15 2018 tchvatal@suse.com
- Drop the debian control things, all releases fail to build
- Update to 1.0.3:
  * Fix various lint issues
  * Switch to SPDX-3.0 license format
  * Add %%doc -> %%license conversion script
  * Fix crash bugs found when scanning whole Tumbleweed repo
* Tue Jan 23 2018 tchvatal@suse.com
- Version update to 1.0.2 bsc#1077177:
  * Allow changelog-year specification via cmdline
  * Switch to pytest
  * Add groups for rust
  * Fix bug in otherprovides removal
* Wed Dec  6 2017 tchvatal@suse.com
- Version update to 1.0.1 bsc#1071561:
  * Recognize new rpm trgger* events
  * Remove otherproviders conflicts syntax (just keep the pkg name)
  * Detect more apache macros
  * Drop py_requires macro that is useless
* Tue Sep 26 2017 tchvatal@suse.com
- Version update to 1.0.0 bsc#1060402:
  * Recognise the BuildConflicts tag
  * Fix few make parsing errors
  * Fix some codeblock error detection
  * More path replacements detection
  * Keep uppercase URL tag as per vote
* Wed Aug  9 2017 tchvatal@suse.com
- Version update to 0.9.9:
  * Include pkgconfig and others from leap 42.3 instead of 42.2
* Thu Jun 29 2017 tchvatal@suse.com
- Version update to 0.9.8 bsc#1046652:
  * Various fixes as reported on github
  * Remove defattr as default from new rpm should be enough
  * Remove buildroot as new rpms do not need it at all
* Mon Jun 12 2017 tchvatal@suse.com
- Version update to 0.9.7:
  * Fix help parsing that crashed the app on execution
* Thu Jun  8 2017 tchvatal@suse.com
- Version update to 0.9.6:
  * Deduplication of requires/buildrequires
  * Preamble detection fixups
  * Detect buildignores
* Wed May 17 2017 tchvatal@suse.com
- Version update to 0.9.5:
  * More fixes for the dep_parser
  * Convert pypy urls to new format
  * Start of rpmpreamble cleanup
* Sat Apr  8 2017 tchvatal@suse.com
- Version update to 0.9.4:
  * Fixes in the dep_parser
  * Vertical whitespace is now safeguarded
  * More excludes_bracketing
  * Update list of known licenses
* Mon Feb 27 2017 mpluskal@suse.com
- Update to version 0.9.3:
  * Fix regression (gh#openSUSE/spec-cleaner#171)
* Mon Feb 13 2017 tchvatal@suse.com
- Version update to 0.9.2:
  * More minimal fixes
  * Add option to keep vertical space in preamble if desired
* Fri Dec 30 2016 tchvatal@suse.com
- Version update to 0.9.1:
  * Switch from regexp macro detection to full-blown parser to avoid
    bugs
* Thu Jun 30 2016 tchvatal@suse.com
- Version update to 0.9.0:
  * Various small fixes
  * Support for tex/perl/cmake conversions:
    + bla-devel -> cmake(bla)
* Mon Jun  6 2016 tchvatal@suse.com
- Version update to 0.8.9:
  * Fix one more virtualenv issue
  * Fix one case of broken requires splitting
  * Properly initialize unbracketing in regexps
  * Fix one more case of double pkg-config dependency
* Thu May 19 2016 tchvatal@suse.com
- Version update to 0.8.8:
  * Various install fixes for pypi
  * Few small fixes for copyiright parsing
  * Add ghc_ macros to known exclude for bracketing
* Wed May 11 2016 tchvatal@suse.com
- Version update to 0.8.5:
  * Fix for pkgconfig adding in preamble section
* Wed May 11 2016 tchvatal@suse.com
- Version update to 0.8.4:
  * 0.8.3 skipped due to pypi mistake
  * set suffix for manpages/infopages
  * remove suse_update_config
  * remove more authors blobs
  * redo options passing to be more readable
  * split out testsuite (now runs ~270 tests)
  * few bracketing excludes updates
  * Fix the no-header option to do what everyone would expect
* Fri Apr 29 2016 tchvatal@suse.com
- Version update to 0.8.2:
  * Add switch to disable copyright generating
  * Few small fixes
  * Tweak pkgconfig addition to work on all distros not just openSUSE
* Thu Apr 14 2016 tchvatal@suse.com
- Version update to 0.8.1:
  * Sort out AUTHORS alphabetically and fix emails
  * Fix FIXME addition to all ./configure calls
  * Fix breakage on some buildrequires syntax
* Wed Apr 13 2016 tchvatal@suse.com
- Version update to 0.8.0:
  * Various bugfixes to the functionality
  * Add fixme to plain ./configure macro
  * Add pkgconfig dependency if needed
  * Add tests for all exclude_bracketing rules
* Wed Mar 23 2016 pjanouch@suse.de
- Added build files for Debian
* Thu Mar  3 2016 tchvatal@suse.com
- Version update to 0.7.9:
  * Fix bug in %%if detection if it was curlified
  * Add one more case of RPM_BUILD_ROOT replacement
  * Detect wrong Group values and suggest correct ones
* Wed Feb 17 2016 tchvatal@suse.com
- Version update to 0.7.8:
  * Various tweaks for the minimal mode
  * Fixed issue with eating up newline after oneline scriptlets
  * Added one more case for section declarations
* Tue Feb  9 2016 tchvatal@suse.com
- Version update to 0.7.7:
  * fix oneline scriptlets from previous version
  * Few small fixes
  * Minimal mode expansion to work reliably as format_spec_file replacement
* Fri Jan 22 2016 tchvatal@suse.com
- Version update to 0.7.5:
  * Replace jobs in install section too
  * Do not curlify gconf_schemas
  * Work with defines in sections not just as global declarations
  * Quote optflags properly when replacing RPM_OPT_FLAGS
  * Do not add empty line after oneline scriptlet
* Thu Sep 17 2015 tchvatal@suse.com
- Version bump to 0.7.4:
  * Use license digger from format_spec_file
  * Provide optional subpkg providing format_spec_file OBS bindings
* Wed Sep  2 2015 tchvatal@suse.com
- Version bump to 0.7.3:
  * Fix wrong bracketing of kernel_module macro
* Fri Jun 26 2015 tchvatal@suse.com
- Version bump to 0.7.2:
  * Do not curlify %%20 which is usually space in Source lines
  * Few more excludes for bracket
  * Bunch of small fixes
* Tue Jun  9 2015 tchvatal@suse.com
- Version bump to 0.7.1:
  * Fix %%config(noreplace) curlification (bnc#934059)
  * Preparation for more path replacements
* Wed Jun  3 2015 tchvatal@suse.com
- Version bump to 0.7.0:
  * Various small code cleanups and readability improvemnets
  * Better macro detection to allow braces in macros
  * Fix minimal mode appending empty lines in some cases
  * Various additional bracketing excludes
* Thu Apr 16 2015 tchvatal@suse.com
- Version bump to 0.6.9:
  * Replace => with >=
  * Bracketing excludes
  * Replace paths using regexps instead of hardcoding (more cases covered)
  * Remove various obsolete tags from preamble Icon/Packager/...
  * Fix RPM_BUILD_ROOT replacement cornercase failure
  * Remove %%doc from %%_mandir paths as it is pointless to have there
* Tue Feb 10 2015 tchvatal@suse.com
- Version bump to 0.6.8:
  * The copyright line broke test, so update again to fix that
* Tue Feb 10 2015 tchvatal@suse.com
- Version bump to 0.6.7:
  * Update copyright line to match current SUSE one
* Tue Feb 10 2015 tchvatal@suse.com
- Version bump to 0.6.6:
  * Excludes for java qmake gem_ and kde macros
  * Cleanup conflicts lines properly
  * Cleanup kernel subpkgs properly
  * Work with spaces in version string
* Mon Dec  8 2014 tchvatal@suse.com
- Version bump to 0.6.5:
  * Fix vertical spacing around nested conditionals
  * Fix issue with bogus %%lang detection
* Sat Nov 15 2014 tchvatal@suse.com
- Remove PKGBUILD until service-download_files is fixed to work fine
  with them
- Version bump to 0.6.4:
  * Various small fixes and macro expansion.
* Sun Oct 12 2014 tchvatal@suse.com
- Version bump to 0.6.3:
  * Fix diff mode
  * Various %%if macro whitespacing issues squashing
  * Base pkgconf conversions from 13.2
* Sun Oct 12 2014 tchvatal@suse.com
- Make us build again for Fedora
* Mon Sep 22 2014 tchvatal@suse.com
- Version bump to 0.6.2:
  * Fix iniline mode
  * Various small fixes and testsuite expansion
* Wed Sep  3 2014 tchvatal@suse.com
- Require py3-setuptools
* Fri Aug 29 2014 tchvatal@suse.com
- py3 include arpgarse itself.
* Wed Aug 13 2014 tchvatal@suse.com
- Version bump to 0.6.1:
  * Fixup release with working spec-cleaner script executable
* Wed Aug 13 2014 tchvatal@suse.com
- Version bump to 0.6.0:
  * Use setuptools and nosetests for building&testing
  * Various bugfixes as found by java icedtea cleaning
* Tue Jul  8 2014 tchvatal@suse.com
- Version bump to 0.5.9:
  * Fix parsing %%endif #comment
  * Fix parsing %%if rigth after %%clean section
* Mon Jun 23 2014 tchvatal@suse.com
- Version bump to 0.5.8:
  * brown paperbag release fixing tests on py3.
* Mon Jun 23 2014 tchvatal@suse.com
- Version bump to 0.5.7:
  * Updates about smp_mflags parsing
  * makeinstall macro replacing improvements.
* Sat May 10 2014 tchvatal@suse.com
- Version bump to 0.5.6:
  * Few minor fixes as reported on github.
* Fri Apr  4 2014 tchvatal@suse.com
- Version bump to 0.5.5:
  * Few minor fixes as reported on github tracker.
* Mon Feb  3 2014 tchvatal@suse.com
- Version bump to 0.5.4:
  * plenty of bugfixes regarding to spec parsing as they were
    reported on github
  * add more exceptions on adding curly brackets
  * update licenses list to the latest.
* Tue Jan 14 2014 tchvatal@suse.com
- Add comment on py3 conditional and depend on python-argparse
* Thu Jan  9 2014 tchvatal@suse.com
- Version bump to 0.5.3:
  + Various parser fixes and extended testsuite coverage
    thanks to reports from packagers team.
* Wed Dec  4 2013 tchvatal@suse.com
- Version bump to 0.5.2:
  + Fixes issues found while parsing libreoffice
  + Fixes issues 4 and 3 on github
* Tue Dec  3 2013 tchvatal@suse.com
- Version bump to 0.5.1:
  + Fixes the conditionals placement and makes all tests pass.
* Fri Nov 29 2013 tchvatal@suse.com
- Version bump to 0.4.2:
  + fix inlining
  + fix service shell script
  + rename obs service to different from format_spec_file
* Mon Nov 25 2013 tchvatal@suse.com
- Fix build on fedora as they bytecompile the py
* Mon Nov 25 2013 tchvatal@suse.com
- Version bump to 0.4.1
  + Fixes to actually be able to parse own specfile.
* Mon Nov 25 2013 tchvatal@suse.com
- Version bump to 0.4.0:
  + Add extensive testsuite
  + Split the code for readability purposes
  + Mimic all the functionality from prep_spec
  + Provide and obsolete obs-service-format_spec_file
* Thu Mar 22 2012 saschpe@suse.de
- Set license to SPDX style (BSD-3-Clause)
* Mon Sep 12 2011 prusnak@opensuse.org
- synchronize obs and git changes
* Thu Jul 14 2011 giecrilj@stegny.2a.pl
- better usage message
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 0.2:
  + Handle suse_version
  + Do not check for AutoReqProv in %%install
  + Replace %%makeinstall by %%make_install
  + Reformat versioned package names too
  + Remove #usedforbuild
  + Replace Patch: with Patch0: (and %%patch with %%patch0)
  + Change default .spec headers to not include any license
  + Replace some package names with pkgconfig()-style names
  + Add --diff and --diff-prog options
  + Put brackets around %%name, %%version, %%release, ...
  + Update url for PATCH-MISSING-TAGw
  + Cut summary after the first dot
  + Add FDL licenses
  + Add .spec extension to spec files created by script
  + Put pkgconfig()-style package names at the end of their list
  + Code improvements
* Mon Dec  6 2010 prusnak@opensuse.org
- update to newer snapshot (1fb8c6db)
  - --diff and --diff-prog options by Petr Uzel
* Thu Sep 30 2010 vuntz@opensuse.org
- Initial package (version 0.1)
